local RayUI, E, L, V, P, G = unpack(select(2, ...))
local RCT = RayUI:GetModule('RayUICombatText')

local function CombatTextTable()
	E.Options.args.rayui.args.modules.args.combattext = {
		type = "group",
        name = L["Combat Text"],
        childGroups = "tab",
		get = function(info) return E.db.rayui.combattext[ info[#info] ] end,
		set = function(info, value) E.db.rayui.combattext[ info[#info] ] = value; RCT:Configure_CombatText(); end,
        args = {
            name = {
                order = 1,
                type = 'header',
                name = L["Combat Text"],
            },
            enable = {
                order = 2,
                type = "toggle",
                name = L["Enable"],
                desc = L["Enable chat panel auto hide"],
                set = function(info, value) E.db.rayui.combattext.enable = value; E:StaticPopup_Show("CONFIG_RL"); end,
            },
            displayFrames = {
                type = 'execute',
                order = 2,
                name = L["Display Frames"],
                func = function() RCT:ToggleForceShowMode() end,
            },
            general = {
                order = 3,
                type = "group",
                guiInline = true,
                name = L["General"],
                args = {
                    mergeDelay = {
                        order = 2,
                        type = "range",
                        name = L["Merge delay"],
                        desc = L["How long to wait before showing events so that merges may happen."],
                        min = 0.1, max = 5, step = 0.1,
                    },
                    fadeTime = {
                        order = 2,
                        type = "range",
                        name = L["Fade Out Delay"],
                        min = 1, max = 10, step = 0.1,
                    },
                },
            },
            fontGroup = {
                order = 4,
                type = "group",
                guiInline = true,
                name = L["Fonts"],
                args = {
                    font = {
                        order = 1,
                        type = "select",
                        dialogControl = 'LSM30_Font',
                        name = L["Font"],
                        values = AceGUIWidgetLSMlists.font,
                    },
                    fontSize = {
                        order = 2,
                        type = "range",
                        name = L["FONT_SIZE"],
                        min = 4, max = 50, step = 1,
                    },
                    fontOutline = {
                        order = 3,
                        type = "select",
                        name = L["Font Outline"],
                        values = {
                            ["NONE"] = L["NONE"],
                            ["OUTLINE"] = "OUTLINE",
                            ["MONOCHROMEOUTLINE"] = "MONOCROMEOUTLINE",
                            ["THICKOUTLINE"] = "THICKOUTLINE"
                        },
                    },
                    iconSize = {
                        order = 4,
                        type = "range",
                        name = L["Icon Size"],
                        min = 10, max = 100, step = 1,
                    },
                },
            },
        },
    }

    local order = 5
    local ftypes = {
        ["outgoing"] = "Outgoing",
        ["incomingDamage"] = "Incoming Damage",
        ["incomingHeal"] = "Incoming Healing",
        ["message"] = "Message"
    }
    for ftype, text in pairs(ftypes) do
        E.Options.args.rayui.args.modules.args.combattext.args[ftype] = {
            order = order,
            name = L[text],
            type = 'group',
            get = function(info) return E.db.rayui.combattext[ftype][ info[#info] ] end,
		    set = function(info, value) E.db.rayui.combattext[ftype][ info[#info] ] = value; RCT:Configure_CombatTextFrame(ftype); end,
            args = {
                width = {
                    order = 1,
                    type = "range",
                    name = L["Width"],
                    min = 50, max = 500, step = 1,
                },
                height = {
                    order = 2,
                    type = "range",
                    name = L["Height"],
                    min = 50, max = 500, step = 1,
                },
                justifyH = {
                    order = 3,
                    type = 'select',
                    name = L["JustifyH"],
                    desc = L["Sets the font instance's horizontal text alignment style."],
                    values = {
                        ['CENTER'] = L["Center"],
                        ['LEFT'] = L["Left"],
                        ['RIGHT'] = L["Right"],
                    },
                }
            }
        }
        order = order + 1
    end
end

tinsert(RayUI.Config, CombatTextTable)
